"use strict";
/*******************************************************************************
 * Copyright (c) 2018, 2019 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v2.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v20.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const vscode = require("vscode");
const CommandUtil_1 = require("./CommandUtil");
const Logger_1 = require("../Logger");
const MCUtil = require("../MCUtil");
const ProjectCreator_1 = require("../microclimate/connection/ProjectCreator");
/**
 * @param create true for Create page, false for Import page
 */
function openCreateOrImportPage(connection) {
    return __awaiter(this, void 0, void 0, function* () {
        if (connection == null) {
            const selected = yield CommandUtil_1.promptForConnection(true);
            if (selected == null) {
                Logger_1.default.d("User cancelled prompt for resource");
                // user cancelled
                return;
            }
            connection = selected;
        }
        try {
            yield ProjectCreator_1.default.createProject(connection);
        }
        catch (err) {
            Logger_1.default.e("Error importing project", err);
            const errMsg = MCUtil.errToString(err);
            vscode.window.showErrorMessage("Error importing project: " + errMsg);
        }
    });
}
exports.default = openCreateOrImportPage;
//# sourceMappingURL=NewMCProjectCmd.js.map