"use strict";
/*******************************************************************************
 * Copyright (c) 2018, 2019 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v2.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v20.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
Object.defineProperty(exports, "__esModule", { value: true });
// non-nls-file
/**
 *  "Regular" endpoints, eg "localhost:9090/api/v1/environment"
 */
var MCEndpoints;
(function (MCEndpoints) {
    MCEndpoints["ENVIRONMENT"] = "api/v1/environment";
    MCEndpoints["PROJECTS"] = "api/v1/projects";
    MCEndpoints["PROJECTS_V2"] = "api/v1/projects";
    MCEndpoints["PROJECT_TYPES"] = "api/v1/project-types";
})(MCEndpoints = exports.MCEndpoints || (exports.MCEndpoints = {}));
/**
 * Project endpoints, eg "localhost:9090/api/v1/project/81eba580-0aea-11e9-b530-67b2995d0cd9/restart"
 */
var ProjectEndpoints;
(function (ProjectEndpoints) {
    ProjectEndpoints["RESTART_ACTION"] = "restart";
    ProjectEndpoints["BUILD_ACTION"] = "build";
    ProjectEndpoints["VALIDATE"] = "validate";
    ProjectEndpoints["GENERATE"] = "validate/generate";
    ProjectEndpoints["PROPERTES"] = "properties";
    ProjectEndpoints["LOGS"] = "logs";
    ProjectEndpoints["METRICS_STATUS"] = "metrics/status";
    ProjectEndpoints["OPEN"] = "open";
    ProjectEndpoints["CLOSE"] = "close";
    ProjectEndpoints["NONE"] = "";
})(ProjectEndpoints = exports.ProjectEndpoints || (exports.ProjectEndpoints = {}));
/**
 * Functions for resolving Portal endpoints
 */
var EndpointUtil;
(function (EndpointUtil) {
    function isProjectEndpoint(endpoint) {
        return Object.values(ProjectEndpoints).includes(endpoint);
    }
    EndpointUtil.isProjectEndpoint = isProjectEndpoint;
    function resolveMCEndpoint(connection, endpoint) {
        return connection.mcUri.toString().concat(endpoint);
    }
    EndpointUtil.resolveMCEndpoint = resolveMCEndpoint;
    function resolveProjectEndpoint(connection, projectID, endpoint) {
        return connection.mcUri.toString().concat(`${MCEndpoints.PROJECTS}/${projectID}/${endpoint}`);
    }
    EndpointUtil.resolveProjectEndpoint = resolveProjectEndpoint;
    function resolveAppMonitorUrl(connection, projectID) {
        return connection.mcUri.with({ query: `project=${projectID}&view=monitor` });
    }
    EndpointUtil.resolveAppMonitorUrl = resolveAppMonitorUrl;
    const QUERY_NEW_PROJECT = "new-project=true";
    const QUERY_IMPORT_PROJECT = "import-project=true";
    function resolveCreateOrImportUrl(connection, create) {
        const query = create ? QUERY_NEW_PROJECT : QUERY_IMPORT_PROJECT;
        return connection.mcUri.with({ query });
    }
    EndpointUtil.resolveCreateOrImportUrl = resolveCreateOrImportUrl;
    function getEnablementAction(enable) {
        return enable ? ProjectEndpoints.OPEN : ProjectEndpoints.CLOSE;
    }
    EndpointUtil.getEnablementAction = getEnablementAction;
})(EndpointUtil = exports.EndpointUtil || (exports.EndpointUtil = {}));
exports.default = EndpointUtil;
//# sourceMappingURL=Endpoints.js.map