"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const vscode = require("vscode");
// export enum MCLogTypes {
//     "app", "build",
// }
const FW_CONTAINER_LOGS_NAME = "-";
const PORTAL_CONTAINER_LOGS_NAME = "container";
const USER_CONTAINER_LOGS_NAME = "container log";
class MCLog {
    constructor(projectName, 
    // MUST match the logName provided in the events
    logName, 
    // public readonly logType: MCLogTypes,
    // path is not used at this time
    logPath) {
        this.logName = logName;
        this.logPath = logPath;
        // portal sends the logName for container logs (in log-update events) as "container", but filewatcher sends "-" (in REST requests)
        // so we have to deal with that here, normalize to the portal name
        const isContainerLog = logName === FW_CONTAINER_LOGS_NAME;
        if (isContainerLog) {
            this.logName = PORTAL_CONTAINER_LOGS_NAME;
        }
        this.displayName = projectName + " - " + (isContainerLog ? USER_CONTAINER_LOGS_NAME : this.logName);
        this.label = this.displayName;
        // this.description = `(${this.logType} log)`;
        // Log.d(`Initialized log ${this.displayName} internal name ${this.logName}`);
    }
    onNewLogs(reset, logs) {
        if (!this.output) {
            return;
        }
        if (reset) {
            // Log.d("Reset " + this.displayName);
            this.output.clear();
        }
        // Log.d(`${this.displayName} appending length ${logs.length}`);
        this.output.append(logs);
    }
    get isOpen() {
        return this.output != null;
    }
    // quickPickItem
    get picked() {
        return this.isOpen;
    }
    removeOutput() {
        // Log.d("Hide log " + this.displayName);
        if (this.output) {
            this.output.dispose();
            this.output = undefined;
        }
    }
    showOutput() {
        // Log.d("Show log " + this.displayName);
        if (!this.output) {
            // Log.d("Creating output for log " + this.displayName);
            this.output = vscode.window.createOutputChannel(this.displayName);
            this.output.show();
            this.output.appendLine("Waiting for Microclimate to send logs...");
        }
    }
    onDisconnectOrDisable(disconnect) {
        if (this.output) {
            let msg = "*".repeat(8) + " This log is no longer updating: ";
            if (disconnect) {
                msg += "Microclimate disconnected.";
            }
            else {
                msg += "the project has been disabled.";
            }
            this.output.appendLine(msg);
        }
    }
    destroy() {
        this.removeOutput();
    }
}
exports.default = MCLog;
//# sourceMappingURL=MCLog.js.map