"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const MCLog_1 = require("./MCLog");
const Logger_1 = require("../../../Logger");
const Requester_1 = require("../Requester");
class MCLogManager {
    constructor(project) {
        this.project = project;
        this._logs = [];
        this.initPromise = this.initialize();
        this.managerName = `${this.project.name} LogManager`;
    }
    initialize() {
        return __awaiter(this, void 0, void 0, function* () {
            if (this._logs.length > 0) {
                Logger_1.default.e(this.managerName + " logs have already been initialized");
                return;
            }
            // Log.d("Initializing logs");
            try {
                const availableLogs = yield Requester_1.default.requestAvailableLogs(this.project);
                availableLogs.app.concat(availableLogs.build).forEach((log) => {
                    this.logs.push(new MCLog_1.default(this.project.name, log.logName, log.workspathLogPath));
                });
                Logger_1.default.i(`${this.managerName} has finished initializing logs: ${this.logs.map((l) => l.displayName).join(", ") || "<none>"}`);
            }
            catch (err) {
                // requester will show the error
                return;
            }
        });
    }
    toString() {
        return this.managerName;
    }
    /**
     * @param enable `true` to refresh (ie, restart) all logs for this project, `false` to stop streaming all logs for this project
     */
    toggleLogStreaming(enable) {
        return __awaiter(this, void 0, void 0, function* () {
            Logger_1.default.d(`${this.managerName} log streaming now ${enable}`);
            yield Requester_1.default.requestToggleLogs(this.project, enable);
        });
    }
    onNewLogs(event) {
        if (event.projectID !== this.project.id) {
            Logger_1.default.e(`${this.managerName} received logs for other project ${event.projectName}`);
            return;
        }
        const existingLog = this.logs.find((log) => log.logName === event.logName);
        if (existingLog != null) {
            existingLog.onNewLogs(event.reset, event.logs);
        }
    }
    onReconnectOrEnable() {
        // Log.d(`${this.managerName} onReconnectOrEnable`);
        // refresh all streams
        this.toggleLogStreaming(true);
    }
    onDisconnectOrDisable(disconnect) {
        // Log.d(`${this.managerName} onDisconnectOrDisable`);
        this.logs.forEach((log) => log.onDisconnectOrDisable(disconnect));
    }
    get logs() {
        return this._logs;
    }
    destroyAllLogs() {
        this.logs.forEach((log) => log.destroy());
    }
}
exports.default = MCLogManager;
//# sourceMappingURL=MCLogManager.js.map