"use strict";
/*******************************************************************************
 * Copyright (c) 2018, 2019 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v2.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v20.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
Object.defineProperty(exports, "__esModule", { value: true });
const vscode = require("vscode");
const ConnectionManager_1 = require("../microclimate/connection/ConnectionManager");
// import Commands from "../constants/Commands";
const Logger_1 = require("../Logger");
const Project_1 = require("../microclimate/project/Project");
const Connection_1 = require("../microclimate/connection/Connection");
const Resources_1 = require("../constants/Resources");
class ProjectTreeDataProvider {
    constructor() {
        this.VIEW_ID = "ext.mc.mcProjectExplorer"; // must match package.nls.json
        this.onTreeDataChangeEmitter = new vscode.EventEmitter();
        this.onDidChangeTreeData = this.onTreeDataChangeEmitter.event;
        /**
         * Notifies VSCode that this tree has to be refreshed.
         * Used as a call-back for ConnectionManager OnChange.
         */
        this.refresh = (treeItem) => {
            // Log.d("refresh tree");
            this.onTreeDataChangeEmitter.fire(treeItem);
        };
        this.treeView = vscode.window.createTreeView(this.VIEW_ID, { treeDataProvider: this });
        ConnectionManager_1.default.instance.addOnChangeListener(this.refresh);
        Logger_1.default.d("Finished constructing ProjectTree");
    }
    static get treeViewInstance() {
        if (ProjectTreeDataProvider._instance == null) {
            this._instance = new ProjectTreeDataProvider();
        }
        return this._instance.treeView;
    }
    static select(item) {
        this.treeViewInstance.reveal(item, { select: true, focus: false });
    }
    getTreeItem(node) {
        if (node instanceof Project_1.default || node instanceof Connection_1.default) {
            return node.toTreeItem();
        }
        else if (node instanceof vscode.TreeItem) {
            return node;
        }
        Logger_1.default.e("Unexpected object to convert to TreeItem", node);
        return node;
    }
    getChildren(node) {
        if (node == null) {
            // root
            // connections are the top-level tree items
            if (ConnectionManager_1.default.instance.connections.length === 0) {
                const noConnectionsTi = new vscode.TreeItem("No connections");
                noConnectionsTi.iconPath = Resources_1.default.getIconPaths(Resources_1.default.Icons.Microclimate);
                noConnectionsTi.tooltip = "Run the New Microclimate Connection command";
                return [noConnectionsTi];
            }
            return ConnectionManager_1.default.instance.connections;
        }
        else if (node instanceof Connection_1.default) {
            return node.getProjects();
        }
        // else if (node instanceof Project) {
        //     return [];
        // }
        return [];
    }
    getParent(node) {
        if (node instanceof Project_1.default) {
            return node.connection;
        }
        else if (node instanceof Connection_1.default) {
            return undefined;
        }
        Logger_1.default.e("Unexpected TreeItem!", node);
        return undefined;
    }
}
exports.default = ProjectTreeDataProvider;
//# sourceMappingURL=ProjectTree.js.map